database_cubic_hecke: Ivan Marin's representations of the cubic Hecke algebra
=============================================================================

Description
-----------

Ivan Marin's representations of the cubic Hecke algebra on 4 strands as Python dictionaries

License
-------

GPL

Upstream Contact
----------------

https://pypi.org/project/database-cubic-hecke/

